@@ -7,6 +7,7 @@ import calendar
 import datetime
 import functools
 import itertools
+import collections
 from datetime import timezone as tz
 from collections.abc import Iterable, Mapping
 
@@ -26,6 +27,8 @@ reqValidCdef = s_config.getJsValidator({
     'properties': {
         'storm': {'type': 'string'},
         'creator': {'type': 'string', 'pattern': s_config.re_iden},
+        'iden': {'type': 'string', 'pattern': s_config.re_iden},
+        'view': {'type': 'string', 'pattern': s_config.re_iden},
         'name': {'type': 'string'},
         'doc': {'type': 'string'},
         'incunit': {
@@ -303,17 +306,18 @@ class _Appt:
     Each such entry has a list of ApptRecs.  Each time the appointment is scheduled, the nexttime of the appointment is
     the lowest nexttime of all its ApptRecs.
     '''
-    def __init__(self, stor, iden, recur, indx, query, creator, recs, nexttime=None):
+    def __init__(self, stor, iden, recur, indx, query, creator, recs, nexttime=None, view=None):
         self.doc = ''
         self.name = ''
         self.stor = stor
         self.iden = iden
-        self.recur = recur # does this appointment repeat
+        self.recur = recur  # does this appointment repeat
         self.indx = indx  # incremented for each appt added ever.  Used for nexttime tiebreaking for stable ordering
         self.query = query  # query to run
-        self.creator = creator # user iden to run query as
+        self.creator = creator  # user iden to run query as
         self.recs = recs  # List[ApptRec]  list of the individual entries to calculate next time from
-        self._recidxnexttime = None # index of rec who is up next
+        self._recidxnexttime = None  # index of rec who is up next
+        self.view = view
 
         if self.recur and not self.recs:
             raise s_exc.BadTime(mesg='A recurrent appointment with no records')
@@ -328,6 +332,8 @@ class _Appt:
             self.nexttime = nexttime
         self.isrunning = False  # whether it is currently running
         self.startcount = 0  # how many times query has started
+        self.errcount = 0  # how many times this appt failed
+        self.lasterrs = collections.deque((), maxlen=5)
         self.laststarttime = None
         self.lastfinishtime = None
         self.lastresult = None
@@ -370,16 +376,19 @@ class _Appt:
             'enabled': self.enabled,
             'recur': self.recur,
             'iden': self.iden,
+            'view': self.view,
             'indx': self.indx,
             'query': self.query,
             'creator': self.creator,
             'recs': [d.pack() for d in self.recs],
             'nexttime': self.nexttime,
             'startcount': self.startcount,
+            'errcount': self.errcount,
             'isrunning': self.isrunning,
             'laststarttime': self.laststarttime,
             'lastfinishtime': self.lastfinishtime,
-            'lastresult': self.lastresult
+            'lastresult': self.lastresult,
+            'lasterrs': list(self.lasterrs)
         }
 
     @classmethod
@@ -387,10 +396,9 @@ class _Appt:
         if val['ver'] != 1:
             raise s_exc.BadStorageVersion(mesg=f"Found version {val['ver']}")  # pragma: no cover
         recs = [ApptRec.unpack(tupl) for tupl in val['recs']]
-        appt = cls(stor, val['iden'], val['recur'], val['indx'], val['query'], val['creator'], recs, val['nexttime'])
+        appt = cls(stor, val['iden'], val['recur'], val['indx'], val['query'], val['creator'], recs, nexttime=val['nexttime'], view=val.get('view'))
         appt.doc = val.get('doc', '')
         appt.name = val.get('name', '')
-        appt.startcount = val['startcount']
         appt.laststarttime = val['laststarttime']
         appt.lastfinishtime = val['lastfinishtime']
         appt.lastresult = val['lastresult']
@@ -489,7 +497,7 @@ class Agenda(s_base.Base):
         await self._load_all()
         for iden, appt in self.appts.items():
             try:
-                self.core.getStormQuery(appt.query)
+                await self.core.getStormQuery(appt.query)
             except Exception as e:
                 logger.warning('Invalid appointment %r found in storage: %r.  Disabling.', iden, e)
                 appt.enabled = False
@@ -553,7 +561,13 @@ class Agenda(s_base.Base):
     async def _storeAppt(self, appt, nexs=False):
         ''' Store a single appointment '''
         full = self._hivenode.full + (appt.iden,)
-        await self.core.hive.set(full, appt.pack(), nexs=nexs)
+        stordict = appt.pack()
+
+        # Don't store ephemeral props
+        for prop in ('startcount', 'errcount', 'lasterrs'):
+            stordict.pop(prop, None)
+
+        await self.core.hive.set(full, stordict, nexs=nexs)
 
     @staticmethod
     def _dictproduct(rdict):
@@ -600,7 +614,7 @@ class Agenda(s_base.Base):
             used
 
         Returns:
-            iden of new appointment
+            Packed appointment definition
         '''
         iden = cdef['iden']
         incunit = cdef.get('incunit')
@@ -608,6 +622,7 @@ class Agenda(s_base.Base):
         reqs = cdef.get('reqs', {})
         query = cdef.get('storm')
         creator = cdef.get('creator')
+        view = cdef.get('view')
 
         recur = incunit is not None
         indx = self._next_indx
@@ -647,7 +662,7 @@ class Agenda(s_base.Base):
                 incvals = (incvals, )
             recs.extend(ApptRec(rd, incunit, v) for (rd, v) in itertools.product(reqdicts, incvals))
 
-        appt = _Appt(self, iden, recur, indx, query, creator, recs, nexttime)
+        appt = _Appt(self, iden, recur, indx, query, creator, recs, nexttime=nexttime, view=view)
         self._addappt(iden, appt)
 
         appt.doc = cdef.get('doc', '')
@@ -692,13 +707,25 @@ class Agenda(s_base.Base):
             raise ValueError('empty query')
 
         if self.enabled:
-            self.core.getStormQuery(query)
+            await self.core.getStormQuery(query)
 
         appt.query = query
         appt.enabled = True  # in case it was disabled for a bad query
 
         await self._storeAppt(appt)
 
+    async def move(self, croniden, viewiden):
+        '''
+        Move a cronjob from one view to another
+        '''
+        appt = self.appts.get(croniden)
+        if appt is None:
+            raise s_exc.NoSuchIden()
+
+        appt.view = viewiden
+
+        await self._storeAppt(appt)
+
     async def delete(self, iden):
         '''
         Delete an appointment
@@ -766,13 +793,19 @@ class Agenda(s_base.Base):
         user = self.core.auth.user(appt.creator)
         if user is None:
             logger.warning('Unknown user %s in stored appointment', appt.creator)
-            await self._markfailed(appt)
+            await self._markfailed(appt, 'unknown user')
             return
 
         locked = user.info.get('locked')
         if locked:
             logger.warning('Cron failed because creator %s is locked', user.name)
-            await self._markfailed(appt)
+            await self._markfailed(appt, 'locked user')
+            return
+
+        view = self.core.getView(iden=appt.view, user=user)
+        if view is None:
+            logger.warning('Unknown view %s in stored appointment', appt.view)
+            await self._markfailed(appt, 'unknown view')
             return
 
         info = {'iden': appt.iden, 'query': appt.query}
@@ -781,11 +814,11 @@ class Agenda(s_base.Base):
 
         task.onfini(functools.partial(self._running_tasks.remove, task))
 
-    async def _markfailed(self, appt):
+    async def _markfailed(self, appt, reason):
         appt.lastfinishtime = appt.laststarttime = time.time()
         appt.startcount += 1
         appt.isrunning = False
-        appt.lastresult = 'Failed due to unknown user'
+        appt.lastresult = f'Failed due to {reason}'
         if not self.isfini:
             await self._storeAppt(appt, nexs=True)
 
@@ -800,10 +833,11 @@ class Agenda(s_base.Base):
         await self._storeAppt(appt, nexs=True)
 
         with s_provenance.claim('cron', iden=appt.iden):
-            logger.info('Agenda executing for iden=%s, user=%s, query={%s}', appt.iden, user.name, appt.query)
+            logger.info('Agenda executing for iden=%s, user=%s, view=%s, query={%s}', appt.iden, user.name, appt.view, appt.query)
             starttime = time.time()
+            success = False
             try:
-                opts = {'user': user.iden}
+                opts = {'user': user.iden, 'view': appt.view}
                 async for node in self.core.eval(appt.query, opts=opts):
                     count += 1
             except asyncio.CancelledError:
@@ -813,9 +847,13 @@ class Agenda(s_base.Base):
                 result = f'raised exception {e}'
                 logger.exception('Agenda job %s raised exception', appt.iden)
             else:
+                success = True
                 result = f'finished successfully with {count} nodes'
             finally:
                 finishtime = time.time()
+                if not success:
+                    appt.errcount += 1
+                    appt.lasterrs.append(result)
                 logger.info('Agenda completed query for iden=%s with result "%s" took %0.3fs',
                             appt.iden, result, finishtime - starttime)
                 appt.lastfinishtime = finishtime
