@@ -89,7 +89,7 @@ class View(s_nexus.Pusher):  # type: ignore
         self.triggers = s_trigger.Triggers(self)
         for _, tdef in self.trigdict.items():
             try:
-                self.triggers.load(tdef)
+                await self.triggers.load(tdef)
 
             except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
                 raise
@@ -212,6 +212,7 @@ class View(s_nexus.Pusher):  # type: ignore
                 yield node
 
     async def callStorm(self, text, opts=None):
+        user = self.core._userFromOpts(opts)
         try:
 
             async for item in self.eval(text, opts=opts):
@@ -222,6 +223,16 @@ class View(s_nexus.Pusher):  # type: ignore
             # primitive version of that item.
             return await s_stormtypes.toprim(e.item)
 
+        except asyncio.CancelledError:
+            logger.warning(f'callStorm cancelled',
+                           extra={'synapse': {'text': text, 'username': user.name, 'user': user.iden}})
+            raise
+
+        except Exception:
+            logger.exception(f'Error during callStorm execution for {{ {text} }}',
+                             extra={'synapse': {'text': text, 'username': user.name, 'user': user.iden}})
+            raise
+
         # Any other exceptions will be raised to
         # callers as expected.
 
@@ -263,7 +274,7 @@ class View(s_nexus.Pusher):  # type: ignore
 
                 # Try text parsing. If this fails, we won't be able to get a storm
                 # runtime in the snap, so catch and pass the `err` message
-                self.core.getStormQuery(text, mode=mode)
+                await self.core.getStormQuery(text, mode=mode)
 
                 shownode = (not show or 'node' in show)
 
@@ -288,12 +299,14 @@ class View(s_nexus.Pusher):  # type: ignore
                 pass
 
             except asyncio.CancelledError:
-                logger.warning('Storm runtime cancelled.')
+                logger.warning('Storm runtime cancelled.',
+                               extra={'synapse': {'text': text, 'username': user.name, 'user': user.iden}})
                 cancelled = True
                 raise
 
             except Exception as e:
-                logger.exception(f'Error during storm execution for {{ {text} }}')
+                logger.exception(f'Error during storm execution for {{ {text} }}',
+                                 extra={'synapse': {'text': text, 'username': user.name, 'user': user.iden}})
                 enfo = s_common.err(e)
                 enfo[1].pop('esrc', None)
                 enfo[1].pop('ename', None)
@@ -644,10 +657,14 @@ class View(s_nexus.Pusher):  # type: ignore
         if trig is not None:
             return self.triggers.get(tdef['iden']).pack()
 
-        user = self.core.auth.user(tdef['user'])
-        self.core.getStormQuery(tdef['storm'])
+        gate = self.core.auth.getAuthGate(tdef['iden'])
+        if gate is not None:
+            raise s_exc.DupIden(mesg='An AuthGate with this iden already exists')
 
-        trig = self.triggers.load(tdef)
+        user = self.core.auth.user(tdef['user'])
+        await self.core.getStormQuery(tdef['storm'])
+
+        trig = await self.triggers.load(tdef)
 
         await self.trigdict.set(trig.iden, tdef)
         await self.core.auth.addAuthGate(trig.iden, 'trigger')
